@@ -103,6 +103,7 @@ def get_instance_info(instances, class_instance):
     # collect info
     state_code = 0
     matching_hint = False
+    matching_hints = 0
     for instance in instances:
         matching_hint = False
         instance_id = instance['Instances'][0]['InstanceId']
@@ -122,6 +123,7 @@ def get_instance_info(instances, class_instance):
             # call a function to check tags and hints
             if check_tag_for_hint(class_instance.tag, instance_tag['Value']):
                 matching_hint = True
+                matching_hints += 1
             tags_list += instance_tag['Key']+":"+instance_tag['Value']+", "
         tags_list = tags_list[:-2]
         if state_code == 16:
@@ -158,6 +160,11 @@ def get_instance_info(instances, class_instance):
             else:
                 print(cs(state_name+"\n"+description+"\nKey Name: "+instance_key_name+"\nTags: "+tags_list, state_color))
                 print("-------")
+    if class_instance.hint:
+        if matching_hints < 1:
+            # no instances found with hint
+            class_instance.set_number_of_instances(0)
+            class_instance.no_instances_found()
 
 def stop_and_start(instances, class_instance):
     """stop and start instances"""
@@ -175,10 +182,10 @@ def stop_and_start(instances, class_instance):
                 tmp_switch = "start-instances"
                 tmp_verbing = cs("starting", "green")
             if class_instance.switch:
-                cmd = "aws ec2 "+class_instance.switch+" --instance-ids "+instance_id+class_instance.selected_region
+                cmd = "aws ec2 "+class_instance.switch+" --instance-ids "+instance_id+" "+class_instance.selected_region
                 run = subprocess.check_output(cmd, shell=True)
             else:
-                cmd = "aws ec2 "+tmp_switch+" --instance-ids "+instance_id+class_instance.selected_region
+                cmd = "aws ec2 "+tmp_switch+" --instance-ids "+instance_id+" "+class_instance.selected_region
                 if tmp_switch == "stop-instances" and class_instance.connect:
                     connect_to_started = True
                 else:
@@ -343,6 +350,14 @@ class ArgHandler:
             print(cs("for more information try:", "lightgrey2"), cs("trafficlight -h", "pink"))
             exit()
 
+    def no_instances_found(self):
+        if self.number_of_instances == 0:
+            if self.pipe:
+                sys.stdout.write('no instances found.\n')
+            else:
+                print(cs("no instances found.", "yellow"))
+            exit()
+
     def get_instances(self):
         """get instances"""
         # if there's no positional arg output info for all instances and do nothing
@@ -448,9 +463,7 @@ def main():
     shell.set_number_of_instances(len(instances))
 
     # no instances found with the tag name given
-    if shell.number_of_instances == 0:
-        print(cs("no instances found.", "yellow"))
-        exit()
+    shell.no_instances_found()
     
     # check for multiple instances before connecting
     shell.multiple_connect_check()
